@@ -1,10 +1,11 @@
 from typing import Any, Callable, List, Optional, Dict, Union
+from typing_extensions import Protocol
 
 import numpy as np  # type: ignore
 from dataclasses import dataclass, field
 
 from code_loader.contract.decoder_classes import LeapImage, LeapText, LeapNumeric, LeapGraph, LeapHorizontalBar, \
-    LeapMask
+    LeapTextMask, LeapImageMask
 from code_loader.contract.enums import DataStateType, DatasetMetadataType, \
     DataStateEnum, LeapDataType
 
@@ -25,15 +26,17 @@ class PreprocessHandler:
 
 
 DecoderCallableInterface = Union[
-    Callable[[np.array], LeapImage],
-    Callable[[np.array], LeapNumeric],
-    Callable[[np.array], LeapText],
-    Callable[[np.array], LeapGraph],
-    Callable[[np.array], LeapHorizontalBar],
-    Callable[[np.array], LeapMask],
+    Callable[..., LeapImage],
+    Callable[..., LeapNumeric],
+    Callable[..., LeapText],
+    Callable[..., LeapGraph],
+    Callable[..., LeapHorizontalBar],
+    Callable[..., LeapImageMask],
+    Callable[..., LeapTextMask],
 ]
 
-DecoderCallableReturnType = Union[LeapImage, LeapNumeric, LeapText, LeapGraph, LeapHorizontalBar, LeapMask]
+DecoderCallableReturnType = Union[LeapImage, LeapNumeric, LeapText,
+                                  LeapGraph, LeapHorizontalBar, LeapImageMask, LeapTextMask]
 
 
 @dataclass
@@ -41,7 +44,7 @@ class DecoderHandler:
     name: str
     function: DecoderCallableInterface
     type: LeapDataType
-    heatmap_function: Optional[Callable[[np.array], np.array]] = None
+    heatmap_function: Optional[Callable[..., np.array]] = None
 
 
 @dataclass
@@ -52,13 +55,17 @@ class DatasetBaseHandler:
 
 @dataclass
 class InputHandler(DatasetBaseHandler):
-    decoder_name: str
     shape: Optional[List[int]] = None
 
 
 @dataclass
-class GroundTruthHandler(DatasetBaseHandler):
+class ConnectionInstance:
     decoder_name: str
+    encoder_names: List[str]
+
+
+@dataclass
+class GroundTruthHandler(DatasetBaseHandler):
     shape: Optional[List[int]] = None
 
 
@@ -74,6 +81,7 @@ class DatasetIntegrationSetup:
     inputs: List[InputHandler] = field(default_factory=list)
     ground_truths: List[GroundTruthHandler] = field(default_factory=list)
     metadata: List[MetadataHandler] = field(default_factory=list)
+    connections: List[ConnectionInstance] = field(default_factory=list)
 
 
 @dataclass
